@@ -8,9 +8,8 @@
 #' @rdname map-shiny
 #' @export
 #' @examples # !formatR
-#' \donttest{library(leaflet)
 #' library(shiny)
-#' app = shinyApp(
+#' app <- shinyApp(
 #'   ui = fluidPage(leafletOutput('myMap')),
 #'   server = function(input, output) {
 #'     map = leaflet() %>% addTiles() %>% setView(-93.65, 42.0285, zoom = 17)
@@ -18,7 +17,7 @@
 #'   }
 #' )
 #'
-#' if (interactive()) print(app)}
+#' \donttest{if (interactive()) app}
 leafletOutput <- function(outputId, width = "100%", height = 400) {
   htmlwidgets::shinyWidgetOutput(outputId, "leaflet", width, height, "leaflet")
 }
@@ -26,6 +25,6 @@ leafletOutput <- function(outputId, width = "100%", height = 400) {
 #' @rdname map-shiny
 #' @export
 renderLeaflet <- function(expr, env = parent.frame(), quoted = FALSE) {
-  if (!quoted) expr = substitute(expr)  # force quoted
+  if (!quoted) expr <- substitute(expr)  # force quoted
   htmlwidgets::shinyRenderWidget(expr, leafletOutput, env, quoted = TRUE)
 }
