@@ -54,16 +54,16 @@ invokeMethod <- function(map, data, method, ...) {
     NULL
   }
 
-  args = evalFormula(list(...), data)
+  args <- evalFormula(list(...), data)
 
   dispatch(map,
     method,
     leaflet = {
-      x = map$x$calls
-      if (is.null(x)) x = list()
-      n = length(x)
-      x[[n + 1]] = list(method = method, args = args)
-      map$x$calls = x
+      x <- map$x$calls
+      if (is.null(x)) x <- list()
+      n <- length(x)
+      x[[n + 1]] <- list(method = method, args = args)
+      map$x$calls <- x
       map
     },
     leaflet_proxy = {
@@ -108,20 +108,19 @@ invokeMethod <- function(map, data, method, ...) {
 #'   \code{TRUE}
 #'
 #' @examples
-#' \donttest{
 #' library(shiny)
 #'
 #' ui <- fluidPage(
 #'   leafletOutput("map1")
 #' )
 #'
+#' map <- leaflet() %>% addCircleMarkers(
+#'   lng = runif(10),
+#'   lat = runif(10),
+#'   layerId = paste0("marker", 1:10))
+
 #' server <- function(input, output, session) {
-#'   output$map1 <- renderLeaflet({
-#'     leaflet() %>% addCircleMarkers(
-#'       lng = runif(10),
-#'       lat = runif(10),
-#'       layerId = paste0("marker", 1:10))
-#'   })
+#'   output$map1 <- renderLeaflet(map)
 #'
 #'   observeEvent(input$map1_marker_click, {
 #'     leafletProxy("map1", session) %>%
@@ -129,9 +128,8 @@ invokeMethod <- function(map, data, method, ...) {
 #'   })
 #' }
 #'
-#' shinyApp(ui, server)
-#'
-#' }
+#' app <- shinyApp(ui, server)
+#' \donttest{if (interactive()) app}
 #'
 #' @export
 leafletProxy <- function(mapId, session = shiny::getDefaultReactiveDomain(),
@@ -152,7 +150,11 @@ leafletProxy <- function(mapId, session = shiny::getDefaultReactiveDomain(),
   # This won't be necessary in future versions of Shiny, as session$ns (and
   # other forms of ns()) will be smart enough to only namespace un-namespaced
   # IDs.
-  if (!is.null(session$ns) && nzchar(session$ns(NULL)) && !startsWith(mapId, session$ns(""))) {
+  if (
+    !is.null(session$ns) &&
+    nzchar(session$ns(NULL)) &&
+    substring(mapId, 1, nchar(session$ns(""))) != session$ns("")
+  ) {
     mapId <- session$ns(mapId)
   }
 
@@ -186,7 +188,7 @@ leafletProxy <- function(mapId, session = shiny::getDefaultReactiveDomain(),
 #
 # When Shiny >0.12.0 goes to CRAN, we should update our version
 # dependency and remove this entire mechanism.
-sessionFlushQueue = new.env(parent = emptyenv())
+sessionFlushQueue <- new.env(parent = emptyenv())
 
 invokeRemote <- function(map, method, args = list()) {
   if (!inherits(map, "leaflet_proxy"))
@@ -228,7 +230,7 @@ invokeRemote <- function(map, method, args = list()) {
           for (msg in sessionFlushQueue[[sess$token]]) {
             sess$sendCustomMessage("leaflet-calls", msg)
           }
-        }, once = TRUE)
+        }, once = TRUE) # nolint
       }
 
       # Append the current value to the apporpriate sessionFlushQueue entry,
@@ -238,7 +240,7 @@ invokeRemote <- function(map, method, args = list()) {
     } else {
       sess$onFlushed(function() {
         sess$sendCustomMessage("leaflet-calls", msg)
-      }, once = TRUE)
+      }, once = TRUE) # nolint
     }
   } else {
     sess$sendCustomMessage("leaflet-calls", msg)
@@ -249,9 +251,9 @@ invokeRemote <- function(map, method, args = list()) {
 # A helper function to generate the body of function(x, y) list(x = x, y = y),
 # to save some typing efforts in writing tileOptions(), markerOptions(), ...
 makeListFun <- function(list) {
-  if (is.function(list)) list = formals(list)
-  nms = names(list)
-  cat(sprintf('list(%s)\n', paste(nms, nms, sep = ' = ', collapse = ', ')))
+  if (is.function(list)) list <- formals(list)
+  nms <- names(list)
+  cat(sprintf("list(%s)\n", paste(nms, nms, sep = " = ", collapse = ", ")))
 }
 
 "%||%" <- function(a, b) {
@@ -263,8 +265,15 @@ makeListFun <- function(list) {
 #' @param lat vector with latitude values
 #' @param funcName Name of calling function
 #' @param warn A boolean. Whether to generate a warning message if there are rows with missing/invalid data
+#' @param mode if \code{"point"} then warn about any \code{NA} lng/lat values;
+#'   if \code{"polygon"} then \code{NA} values are expected to be used as
+#'   polygon delimiters
 #' @export
-validateCoords <- function(lng, lat, funcName, warn=T) {
+validateCoords <- function(lng, lat, funcName, warn = TRUE,
+  mode = c("point", "polygon")) {
+
+  mode <- match.arg(mode)
+
   if (is.null(lng) && is.null(lat)) {
     stop(funcName, " requires non-NULL longitude/latitude values")
   } else if (is.null(lng)) {
@@ -280,15 +289,21 @@ validateCoords <- function(lng, lat, funcName, warn=T) {
   } else if (!is.numeric(lat)) {
     stop(funcName, " requires numeric latitude values")
   }
-  complete <- ifelse(
-    is.na(lat) | is.null(lat) | is.na(lng) | is.null(lng) |
-      !is.numeric(lat) | !is.numeric(lng),
-    FALSE, TRUE)
 
-  if(any(!complete)) {
-    warning(sprintf("Data contains %s rows with either missing or invalid lat/lon values and will be ignored",sum(!complete)))
+  if (mode == "point") {
+    incomplete <- is.na(lat) | is.na(lng)
+   if (any(incomplete)) {
+      warning(sprintf("Data contains %s rows with either missing or invalid lat/lon values and will be ignored", sum(incomplete))) # nolint
+    }
+  } else if (mode == "polygon") {
+    incomplete <- is.na(lat) != is.na(lng)
+   if (any(incomplete)) {
+      warning(sprintf("Data contains %s rows with either missing or invalid lat/lon values and will be ignored", sum(incomplete))) # nolint
+    }
+    lng <- lng[!incomplete]
+    lat <- lat[!incomplete]
   }
 
-  data.frame(lng=lng,lat=lat)
+  data.frame(lng = lng, lat = lat)
 
 }
